# -*- coding: utf-8 -*-
# Copyright (C) 2008 Warp Networks S.L.
# Author:  Pablo Martí
"""
Example DBus client

I will configure a connection with some preferences. I obtain the device
udi as the only argument to the script i.e.

$ ./client2.py /org/freedesktop/Hal/devices/usb_device_12d1_1003_noserial
"""

import sys
import traceback

import gobject

import dbus
import dbus.mainloop.glib

from wader.common.consts import (WADER_SERVICE, WADER_OBJPATH, WADER_INTFACE,
                               CRD_INTFACE)

from wader.common.hardware import CONN_OPTS_REV, BAND_OPTS_REV

def handle_response(resp=None):
    """
    Callback for methods that emit output or not
    """
    if resp:
        print "Response", resp
    else:
        print "No response"

def handle_error(resp):
    """
    Handles any error occurred
    """
    print "ERROR", resp

def remove_device():
    """
    Removes the device specified by C{sys.argv[1]}
    """
    print "Removing device after configuring it"
    remote_object.RemoveDevice(sys.argv[1],
                               dbus_interface=WADER_INTFACE,
                               reply_handler=handle_response,
                               error_handler=handle_error)
    return True


def obtain_device():
    """
    Obtains the device specified by C{sys.argv[1]}
    """
    remote_object.AddDevice(sys.argv[1],
                            dbus_interface=WADER_INTFACE,
                            reply_handler=handle_get_device,
                            error_handler=handle_error)

    return False


def handle_get_device(opath):
    """
    Obtains a reference to C{opath} and starts device operations
    """
    # now we've obtained a proxy to the object
    device_object = bus.get_object(WADER_SERVICE, opath)
    # Enable it
    device_object.Enable(dbus_interface=CRD_INTFACE,
                         reply_handler=handle_response,
                         error_handler=handle_error)
    # in 1.5seconds configure the connection
    gobject.timeout_add(1500, configure_conn, device_object)

def configure_conn(device_object):
    """
    Configures the connection in C{device_object}
    """
    # we want 3GONLY and a WCDMA2100 band
    conf = dict(conn=CONN_OPTS_REV['3GONLY'],
                band=BAND_OPTS_REV['U2100'])
    #conf = dict(conn=1, band=4)
    # issue the ConfigureConnection command
    device_object.ConfigureConnection(conf,
                           dbus_interface=CRD_INTFACE,
                           reply_handler=handle_configure_conn,
                           error_handler=handle_error)

def handle_configure_conn(response=None):
    handle_response(response)
    gobject.timeout_add(3000, remove_device)
    return False

if __name__ == '__main__':
    if not len(sys.argv):
        raise SystemExit("You must specify a device root udi")

    dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
    bus = dbus.SessionBus()
    try:
        # get a reference to the main WADER object
        remote_object = bus.get_object(WADER_SERVICE, WADER_OBJPATH)
    except dbus.DBusException:
        traceback.print_exc()
        sys.exit(1)

    # Start the chained calls in 1s
    gobject.timeout_add(1000, obtain_device)

    loop = gobject.MainLoop()
    loop.run()

