from twisted.python import log

from wader.common.hardware.option import (OptionWCDMADevicePlugin,
                                        OptionWCDMACustomizer)
from wader.common.sim import SIMBaseClass
from wader.common.statem.auth import AuthStateMachine
from epsilon.modal import mode


class OptionColtAuthStateMachine(AuthStateMachine):
    """
    Custom AuthStateMachine for Option Colt

    This device has a rather buggy firmware that yields all sort of
    weird errors. For example, if PIN authentication is disabled on the SIM
    and you issue an AT+CPIN? command, it will reply with a +CPIN: SIM PUK2
    """
    pin_needed_status = AuthStateMachine.pin_needed_status
    puk_needed_status = AuthStateMachine.puk_needed_status
    puk2_needed_status = AuthStateMachine.puk2_needed_status

    class get_pin_status(mode):
        """
        Ask the PIN what's the PIN status

        The SIM can be in one of the following states:
        - SIM is ready (already authenticated, or PIN disabled)
             - PIN is needed
             - PIN2 is needed (not handled)
             - PUK is needed
             - PUK2 is needed
             - SIM is not inserted
             - SIM's firmware error
        """
        def __enter__(self):
            pass
        def __exit__(self):
            pass

        def do_next(self):
            log.msg("Instantiating get_pin_status mode....")
            d = self.device.sconn.get_pin_status()
            d.addCallback(self.get_pin_status_cb)
            d.addErrback(self.sim_failure_eb)
            d.addErrback(self.sim_busy_eb)
            d.addErrback(self.sim_no_present_eb)
            d.addErrback(log.err)


class OptionColtSIMClass(SIMBaseClass):
    """Huawei E220 SIM Class"""
    def __init__(self, sconn):
        super(OptionColtSIMClass, self).__init__(sconn)

    def initialize(self, set_encoding=False):
        self.charset = 'IRA'
        d = super(OptionColtSIMClass, self).initialize(set_encoding)
        d.addCallback(lambda size: self.set_size(size))
        return d

class OptionColtCustomizer(OptionWCDMACustomizer):
    """L{wader.common.hardware.Customizer} for Option Colt"""
    authklass = OptionColtAuthStateMachine


class OptionColt(OptionWCDMADevicePlugin):
    """L{wader.common.plugin.DBusDevicePlugin} for Option Colt"""
    name = "Option Colt"
    version = "0.1"
    author = u"Pablo Martí"
    custom = OptionColtCustomizer()
    simklass = OptionColtSIMClass

    __remote_name__ = "129"

    __properties__ = {
        'usb_device.vendor_id' : [0x0af0],
        'usb_device.product_id' : [0x5000],
    }


optioncolt = OptionColt()
