# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
setuptools file for Wader
"""

import os

from ez_setup import use_setuptools; use_setuptools()
from setuptools import setup, find_packages

from wader.common.consts import (APP_VERSION, APP_NAME,
                               TOP_DIR, APP_SLUG_NAME)

DATA_DIR = os.path.join(TOP_DIR, 'usr', 'share', '%s' % APP_SLUG_NAME)
BIN_DIR = os.path.join(TOP_DIR, 'usr', 'bin')
RESOURCES = os.path.join(DATA_DIR, 'resources')

def list_files(path, exclude=None):
    result = []
    def walk_callback(arg, directory, files):
        for ext in ['.svn', '.git']:
            if ext in files:
                files.remove(ext)
        if exclude:
            for file in files:
                if file.startswith(exclude):
                    files.remove(file)
        result.extend(os.path.join(directory, file) for file in files
                      if not os.path.isdir(os.path.join(directory, file)))

    os.path.walk(path, walk_callback, None)
    return result

data_files = [
   (os.path.join(RESOURCES, 'extra'), list_files('resources/extra')),
   (os.path.join(RESOURCES, 'config'), list_files('resources/config',
                                                exclude="es.warp")),
   (os.path.join(DATA_DIR, 'plugins'), list_files('plugins')),
   (DATA_DIR, ['core-tap.py']),
   (BIN_DIR, ['bin/restart-wader-core']),
]

excluded_packages = [
    'wader.gtk', 'wader.gtk.*'
]

setup(name=APP_NAME,
      version=APP_VERSION,
      description='3G device manager for Linux',
      download_url="http://public.warp.es/wader",
      author='Pablo Martí Gamboa',
      author_email='pmarti@warp.es',
      license='GPL',
      packages=find_packages(exclude=excluded_packages),
      data_files=data_files,
      zip_safe=False,
      test_suite='wader.test',
      classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: No Input/Output (Daemon)',
        'Framework :: Twisted',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Natural Language :: English',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Topic :: Communications :: Telephony',
        ]
)
